==> pgadmin4-9.11-arm64.zip: pgAdmin 4.app/Contents/Frameworks/Python.framework/Versions/3.13/Frameworks/Tcl.framework/Versions/8.6/._tclooConfig.sh <==
    Mac OS X            	   2  /     /                                      ATTR      /  l  .W                 l     com.apple.cs.CodeDirectory     8  ,  com.apple.cs.CodeEntitlements      
d     com.apple.cs.CodeRequirements           com.apple.cs.CodeRequirements-1    ,  #[  com.apple.cs.CodeSignature     /   <  com.apple.quarantine               4                     Iorg.pgadmin.pgadmin4 TCHGL2R7C5 (NEg;(P.(                                        B,4C}è\_6                    TUaEڛnZMX$~qq  ,<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
    <!--
        Disable Sandboxing. This must be enabled for the app store, but it will
        cause Electron to fail to start with an error like:

            [1004/170922.238911:ERROR:directory_reader_posix.cc(42)] opendir /dev/fd: Operation not permitted (1)

        We should figure out why that happens and fix it one day, but for now
        we just don't support the app store.
    -->
    <key>com.apple.security.app-sandbox</key>
    <false/>

    <!--
        Set the app group name for IPC and access to shared containers between
        our processes.
    -->
    <key>com.apple.security.application-groups</key>
    <string>TCHGL2R7C5.org.pgadmin.pgadmin4</string>

    <!--
        We have no need for JIT on x86_64, but Electron won't start without it
        on Apple Silicon.
    -->
    <key>com.apple.security.cs.allow-jit</key>
    <true/>

    <!--
        Explicitly disallow executable code overwriting/patching.
    -->
    <key>com.apple.security.cs.allow-unsigned-executable-memory</key>
    <false/>

    <!--
        Explicitly disallow use of dynamic loader environment variables that
        could be used for code injection.
    -->
    <key>com.apple.security.cs.allow-dyld-environment-variables</key>
    <false/>

    <!--
        Explicitly ensure that library validation is enabled so we only load
        libraries and frameworks signed by us or Apple.
    -->
    <key>com.apple.security.cs.disable-library-validation</key>
    <false/>

    <!--
        We need to enable this, even though we don't modify our own executables.
        Otherwise, Electron just bombs out.
    -->
    <key>com.apple.security.cs.disable-executable-page-protection</key>
    <true/>

    <!--
        We're not a debugger (well, except for procedural languages in Postgres,
        but that doesn't count).
    -->
    <key>com.apple.security.cs.debugger</key>
    <false/>
</dict>
</plist>
                            org.pgadmin.pgadmin4                  
*Hcd                   
*Hcd
                
subject.OU        
TCHGL2R7C5               4                      Iorg.pgadmin.pgadmin4 TCHGL2R7C5 :F'./Na6洁8                                                                 Zh<W5|mhԭU'A}                                2LӁvKT=fwQ}0	*H
010
	`He 0	*H
  k00z!0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120201221215Z
270201221215Z0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 vO[A#+_s?5
?$?O>mG	V)甝5
ʹ`)xEii`k_#:"1O4YBx.3E
EoZ[:2m6lp&D{HX#ş9~]2_R@꾬d[jDl>İ&{^j=GX1? v(mNi&NVtKfxLY 00UW|-,T0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd 0
	*H
  B9tkƤ7*
D,Ya2Կ;P9jDt[pKl#q-_œpe-xXI(3 zvOߨJVg/>ă:wmt.#Qo`H»ZFE~' "rorPu=%] 6H9;ꐀ.`x
S>O2VMxଚBzFXV,*EK4aUD'sNp000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!00$]F0
	*H
 0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
231127141403Z
270201221215Z010
	&,d
TCHGL2R7C51:08U1Developer ID Application: David Page (TCHGL2R7C5)10U
TCHGL2R7C510U

David Page10	UGB0"0
	*H
  0
 b5BvE}ɮKz:Pfxݛ:@%Ƀ$PnUc?KVZAC˔`qRI/"<9?DqlySV gg_?`[ǫ2af2
Ja1)o;mp{Rf'9$t7`1 r-KbkQS.̖xT#MG噢4A>A$SZuYTk󖢭o(APܖ	 00U0 0U#0W|-,T0@+40200+0$http://ocsp.apple.com/ocsp03-devid060U 00	*Hcd00+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.06+*http://www.apple.com/certificateauthority/0U%0
+0UTaTd0D}eE0U0
*Hcd!20231127000000Z0
*Hcd
 0
	*H
  rnaXKyI7 :va=a1L2L-ZZL2eKh{I ʻ`HpUtƺݵMf
;i)wt6&tT!20$iD]8:ME<dj8eRr*Wo)~'
	'[B즚nC;$!10?AvfD?-oR`"}Z$6ui(5eRJ!1000y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS$]F0
	`He %0	*H
	1	*H
0	*H
	1
260129013908Z0/	*H
	1" i>ڵQdbwC۵3I+ֳtX몭0[	*Hcd	1N0+)_#\ztD6[$,a0-	`He G?VnruiΨRdW|Sx$0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>cdhashes</key>
	<array>
		<data>
		Ke5fI1x6h3T3RLG87hUYNlskLGE=
		</data>
		<data>
		6Uc/VshutgLlcpzUdedp3c6oUmQ=
		</data>
	</array>
</dict>
</plist>
0
	*H
  Gth079[0cT?9\TVv[rt)y^q3oQdG?2j{)lKTeWFZovehulTʬZ>ŉU!g麹aż) órY0 eJ3GOnJQ	\*j@bnL6Y71K`ivڋ9
_o=DMA[<+f])бd~U3f[Ǔչ`yЬi5Jء0*H
	10	*H
010	+ 0{*H
	lj0h*010
	`He  NME57N}gט	$~Mw/*/r20260129013908Z0	 TW^
00{E0Q;0
	*H
 0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
260105174054Z
260216174053Z0A10UTimestamp Signer MA110U

Apple Inc.10	UUS0"0
	*H
  0
 t]o5O(㦣l^F`tQ<GH#Si\qz/ $.H^=3H.Cz[I9;4%
PF5tld}} gX7	WӖ=o=Br#s^^ψ!zl|j 
ӡi	XmHj "ߝDm1汼)k1	"@{ φ2;+\R\VeA 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
+03U,0*0(&$"http://crl.apple.com/timestamp.crl0UGZ(cVynw.0U0
	*H
  ?֤1R?ǫ .udi9Vg\]{P?\h}pAcy
>G%̇3HK iXA˾s)rCJ56!x*O#G+0K	dK$MnרO?@Ŧ'hBޭ
މASVO@C]>{6%@nm|?A"00}LWc0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120405120244Z
270405120244Z0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 wg\.#g>B	}
s@/P'4p
<No97ڞecIm] 9	:JidF5ea.
=o%L	x"!{[ѣ~I;
r3,JZr
9Pt(ny_~VVlĮ (tM&By^`EXQI^JMs{Rˣ]klt-D>a>E~4u&@u0Kw 00U4%N78X&)0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd	 0
	*H
  6qS#xe[#Ǣϴ(p!93rC=BQu]ˌjj:T}k>mzT_Cv\ N<>r4\ge0B4ӧBsu|QC`ܮ'kg3EoɘMiKEN"W""En?厸F\ɰ:m7(FeoUhR>?&:k22H;Kу000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS{E0Q;0	+ 0	*H
	1
*H
	0	*H
	1
260129013908Z0#	*H
	10-2r-l/-c0+*H
	10004,yz9_0
	*H
  Kg`$:Ȝ*iM9ft _VɘQߠ߽q}s
DZ8JXOK.ɤ㳾|ZzJQΆ90ȁvNwVޜ MFB*N(M
άB{}^o|?HM-,<-T*F\)k5:!*kĚ[HP*^1EsPhyx!V؞| TOh;07fh=
7p+      q/0083;68e445db;Safari;D4948E6E-9DE1-4187-A0B6-C3D05B3684A0 

==> pgadmin4-9.12-arm64.zip: pgAdmin 4.app/Contents/Frameworks/Python.framework/Versions/3.13/Frameworks/Tcl.framework/Versions/8.6/._tclooConfig.sh <==
    Mac OS X            	   2  /     /                                      ATTR      /  l  .V                 l     com.apple.cs.CodeDirectory     8  ,  com.apple.cs.CodeEntitlements      
d     com.apple.cs.CodeRequirements           com.apple.cs.CodeRequirements-1    ,  #Z  com.apple.cs.CodeSignature     /   <  com.apple.quarantine               4                     Iorg.pgadmin.pgadmin4 TCHGL2R7C5 (NEg;(P.(                                        B,4C}è\_6                    TUaEڛnZMX$~qq  ,<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
    <!--
        Disable Sandboxing. This must be enabled for the app store, but it will
        cause Electron to fail to start with an error like:

            [1004/170922.238911:ERROR:directory_reader_posix.cc(42)] opendir /dev/fd: Operation not permitted (1)

        We should figure out why that happens and fix it one day, but for now
        we just don't support the app store.
    -->
    <key>com.apple.security.app-sandbox</key>
    <false/>

    <!--
        Set the app group name for IPC and access to shared containers between
        our processes.
    -->
    <key>com.apple.security.application-groups</key>
    <string>TCHGL2R7C5.org.pgadmin.pgadmin4</string>

    <!--
        We have no need for JIT on x86_64, but Electron won't start without it
        on Apple Silicon.
    -->
    <key>com.apple.security.cs.allow-jit</key>
    <true/>

    <!--
        Explicitly disallow executable code overwriting/patching.
    -->
    <key>com.apple.security.cs.allow-unsigned-executable-memory</key>
    <false/>

    <!--
        Explicitly disallow use of dynamic loader environment variables that
        could be used for code injection.
    -->
    <key>com.apple.security.cs.allow-dyld-environment-variables</key>
    <false/>

    <!--
        Explicitly ensure that library validation is enabled so we only load
        libraries and frameworks signed by us or Apple.
    -->
    <key>com.apple.security.cs.disable-library-validation</key>
    <false/>

    <!--
        We need to enable this, even though we don't modify our own executables.
        Otherwise, Electron just bombs out.
    -->
    <key>com.apple.security.cs.disable-executable-page-protection</key>
    <true/>

    <!--
        We're not a debugger (well, except for procedural languages in Postgres,
        but that doesn't count).
    -->
    <key>com.apple.security.cs.debugger</key>
    <false/>
</dict>
</plist>
                            org.pgadmin.pgadmin4                  
*Hcd                   
*Hcd
                
subject.OU        
TCHGL2R7C5               4                      Iorg.pgadmin.pgadmin4 TCHGL2R7C5 :F'./Na6洁8                                                                 Zh<W5|mhԭU'A}                                2LӁvKT=fwQ}0	*H
010
	`He 0	*H
  k00z!0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120201221215Z
270201221215Z0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 vO[A#+_s?5
?$?O>mG	V)甝5
ʹ`)xEii`k_#:"1O4YBx.3E
EoZ[:2m6lp&D{HX#ş9~]2_R@꾬d[jDl>İ&{^j=GX1? v(mNi&NVtKfxLY 00UW|-,T0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd 0
	*H
  B9tkƤ7*
D,Ya2Կ;P9jDt[pKl#q-_œpe-xXI(3 zvOߨJVg/>ă:wmt.#Qo`H»ZFE~' "rorPu=%] 6H9;ꐀ.`x
S>O2VMxଚBzFXV,*EK4aUD'sNp000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!00$]F0
	*H
 0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
231127141403Z
270201221215Z010
	&,d
TCHGL2R7C51:08U1Developer ID Application: David Page (TCHGL2R7C5)10U
TCHGL2R7C510U

David Page10	UGB0"0
	*H
  0
 b5BvE}ɮKz:Pfxݛ:@%Ƀ$PnUc?KVZAC˔`qRI/"<9?DqlySV gg_?`[ǫ2af2
Ja1)o;mp{Rf'9$t7`1 r-KbkQS.̖xT#MG噢4A>A$SZuYTk󖢭o(APܖ	 00U0 0U#0W|-,T0@+40200+0$http://ocsp.apple.com/ocsp03-devid060U 00	*Hcd00+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.06+*http://www.apple.com/certificateauthority/0U%0
+0UTaTd0D}eE0U0
*Hcd!20231127000000Z0
*Hcd
 0
	*H
  rnaXKyI7 :va=a1L2L-ZZL2eKh{I ʻ`HpUtƺݵMf
;i)wt6&tT!20$iD]8:ME<dj8eRr*Wo)~'
	'[B즚nC;$!10?AvfD?-oR`"}Z$6ui(5eRJ!1000y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS$]F0
	`He %0	*H
	1	*H
0	*H
	1
260225013714Z0/	*H
	1" i>ڵQdbwC۵3I+ֳtX몭0[	*Hcd	1N0+)_#\ztD6[$,a0-	`He G?VnruiΨRdW|Sx$0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>cdhashes</key>
	<array>
		<data>
		Ke5fI1x6h3T3RLG87hUYNlskLGE=
		</data>
		<data>
		6Uc/VshutgLlcpzUdedp3c6oUmQ=
		</data>
	</array>
</dict>
</plist>
0
	*H
  C5"F"MSB?X}Ǆ(q8" UP!O t6	`R}؁(E5D&20p(S$8ɠQ7x pӎB^@$z2Zc=T,
q ;9B{ 17~y
Edۿ0lԑ!GićB=yy6HMN%b2lzO1ܸ}pd=qr]j+0*H
	10	*H
010	+ 0z*H
	ki0g*010
	`He  )n|u;<لn4k[Q"&20260225013714Z0\cq4
00wZ"C0
	*H
 0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
260202174540Z
260316174539Z0A10UTimestamp Signer MA110U

Apple Inc.10	UUS0"0
	*H
  0
 #6p8̹(B5H^cPGFHZ '@mL@/!c /g
lZ,Pʹad|-MEGjmsLũ0fheٸ )4_"Fshbrx`˷>OAw֚<P 0X줪 ̷?-M/a*.{,Pu^tzA'Xz۲Vlv@܉a:9 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
+03U,0*0(&$"http://crl.apple.com/timestamp.crl0U0g,6t`=Eod0U0
	*H
  +h\`+vq
(9\9CMvjRu0l c9(O*yd5uTi
j\CpCŹln*Ja9)GNk2WpՕc_&$!oM_}¯ӵܷ o\(O<'W_9+N˨bc	Ai"TWŐ~w3	1
@zI(PQLl.JU>00}LWc0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120405120244Z
270405120244Z0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 wg\.#g>B	}
s@/P'4p
<No97ڞecIm] 9	:JidF5ea.
=o%L	x"!{[ѣ~I;
r3,JZr
9Pt(ny_~VVlĮ (tM&By^`EXQI^JMs{Rˣ]klt-D>a>E~4u&@u0Kw 00U4%N78X&)0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd	 0
	*H
  6qS#xe[#Ǣϴ(p!93rC=BQu]ˌjj:T}k>mzT_Cv\ N<>r4\ge0B4ӧBsu|QC`ܮ'kg3EoɘMiKEN"W""En?厸F\ɰ:m7(FeoUhR>?&:k22H;Kу000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUSwZ"C0	+ 0	*H
	1
*H
	0	*H
	1
260225013714Z0#	*H
	1.57Cp2%z0+*H
	1000dldzK#G{:R0
	*H
  &m[6^b6Gyeu!m5?J*6Js\ĹRsA_+ZܺQrߦN^J9ꁾJԬ¯|>(p0<X|Z]߀Sg%	Or:
gX+J877gT0y}^

3351!4ܣF6voR	K\J'h	qCӏho/{pu*{/	ܒ`OD!b+o\;\A      q/0083;68e445db;Safari;D4948E6E-9DE1-4187-A0B6-C3D05B3684A0 
